@@ -7,12 +7,12 @@
 #' @param ... Options passed on to \code{\link[utils]{read.table}}
 #'
 #' @return data.frame
-load_lagos_txt <- function(file_name, sep = "\t", ...){
+load_lagos_txt <- function(file_name, sep = "\t", ...) {
 
   suppressWarnings(
     read.table(file_name, header = TRUE, sep = sep, quote = "\"",
-             dec = ".", strip.white = TRUE, comment.char = "",
-             stringsAsFactors = FALSE))
+      dec = ".", strip.white = TRUE, comment.char = "",
+      stringsAsFactors = FALSE))
 }
 
 #' Summarize all LAGOSNE flat files
@@ -25,7 +25,7 @@ load_lagos_txt <- function(file_name, sep = "\t", ...){
 #' lg <- lagosne_load("1.087.3")
 #' LAGOSNE:::info_table(lg)
 #' }
-info_table <- function(lg){
+info_table <- function(lg) {
 
   limno_names <- c("epi_nutr", "lakes_limno")
   geo_names   <- !(names(lg) %in% c(limno_names, "locus", "lagos_source_program"))
@@ -35,30 +35,30 @@ info_table <- function(lg){
 
   name <- c(names(geo), names(limno), "lagos_source_program")
   type <- c(rep("geo", length(geo)), rep("limno", length(limno)), "source")
-  identifier <- c("county_zoneid","county_zoneid","county_zoneid",
-                  "county_zoneid", "edu_zoneid", "edu_zoneid", "edu_zoneid",
-                  "edu_zoneid", "hu4_zoneid", "hu4_zoneid", "hu4_zoneid",
-                  "hu4_zoneid", "hu8_zoneid", "hu8_zoneid", "hu8_zoneid",
-                  "hu8_zoneid", "hu12_zoneid", "hu12_zoneid", "hu12_zoneid",
-                  "hu12_zoneid", "iws_zoneid","iws_zoneid", "iws_zoneid",
-                  "state_zoneid", "state_zoneid", "state_zoneid",
-                  "state_zoneid", "lagoslakeid", "lagoslakeid",
-                  "lagoslakeid", "lagoslakeid", "lagoslakeid",
-                  "lagoslakeid", "lagoslakeid, eventida10873, programname",
-                  "lagoslakeid", "programname, sourceid")
+  identifier <- c("county_zoneid", "county_zoneid", "county_zoneid",
+    "county_zoneid", "edu_zoneid", "edu_zoneid", "edu_zoneid",
+    "edu_zoneid", "hu4_zoneid", "hu4_zoneid", "hu4_zoneid",
+    "hu4_zoneid", "hu8_zoneid", "hu8_zoneid", "hu8_zoneid",
+    "hu8_zoneid", "hu12_zoneid", "hu12_zoneid", "hu12_zoneid",
+    "hu12_zoneid", "iws_zoneid", "iws_zoneid", "iws_zoneid",
+    "state_zoneid", "state_zoneid", "state_zoneid",
+    "state_zoneid", "lagoslakeid", "lagoslakeid",
+    "lagoslakeid", "lagoslakeid", "lagoslakeid",
+    "lagoslakeid", "lagoslakeid, eventida10873, programname",
+    "lagoslakeid", "programname, sourceid")
 
   # number of variables of each data.frame in the list
   variables <- rep(0, length(name))
 
-  for(i in seq_along(name)){
-    if(type[i] == "geo"){
+  for (i in seq_along(name)) {
+    if (type[i] == "geo") {
       j            <- which(names(geo) == name[i])
       variables[i] <- ncol(geo[[j]])
-    }else{
+    } else {
       j <- which(names(limno) == name[i])
-      if(length(j) != 0){
+      if (length(j) != 0) {
         variables[i] <- ncol(limno[[j]])
-      }else{
+      } else {
         variables[i] <- ncol(lg[[
           names(lg)[which(names(lg) == name[i])]]])
       }
@@ -68,16 +68,16 @@ info_table <- function(lg){
   # Number of observation of each dataframe in the table
   observations <- rep(0, length(name))
 
-  for(i in seq_along(name)){
-    if(type[i] == "geo"){
+  for (i in seq_along(name)) {
+    if (type[i] == "geo") {
       j <- which(names(geo) == name[i])
       observations[i] <- nrow(geo[[j]])
-    }else{
+    } else {
       j <- which(names(limno) == name[i])
 
-      if(length(j) != 0){
+      if (length(j) != 0) {
         observations[i] <- nrow(limno[[j]])
-      }else{
+      } else {
         observations[i] <- nrow(lg[[
           names(lg)[which(names(lg) == name[i])]]])
       }
@@ -86,36 +86,36 @@ info_table <- function(lg){
   }
 
   group <- c(1, 1, 1, 1,
-             2, 2, 2, 2,
-             3, 3, 3, 3,
-             4, 4, 4, 4,
-             5, 5, 5, 5,
-             6, 6, 6,
-             7, 7, 7, 7,
-             10, 10, 10, 10, 10,
-             11, 11, 11,
-             13)
+    2, 2, 2, 2,
+    3, 3, 3, 3,
+    4, 4, 4, 4,
+    5, 5, 5, 5,
+    6, 6, 6,
+    7, 7, 7, 7,
+    10, 10, 10, 10, 10,
+    11, 11, 11,
+    13)
 
-  data.frame(name= I(name),
-    type= I(type),
-    variables=I(variables),
-    observations=I(observations),
-    identifier= I(identifier),
+  data.frame(name = I(name),
+    type = I(type),
+    variables = I(variables),
+    observations = I(observations),
+    identifier = I(identifier),
     group = I(group))
 
 }
 
 #' @importFrom curl curl_download
-get_if_not_exists <- function(url, destfile, overwrite){
-  if(!file.exists(destfile) | overwrite){
+get_if_not_exists <- function(url, destfile, overwrite) {
+  if (!file.exists(destfile) | overwrite) {
     curl::curl_download(url, destfile)
-  }else{
+  } else {
     message(paste0("A local copy of ", url, " already exists on disk"))
   }
 }
 
 stop_if_not_exists <- function(src_path) {
-  if(!file.exists(src_path)){
+  if (!file.exists(src_path)) {
     stop(paste0("Dataset not found at: ", src_path, "\n Try running the `lagosne_get` command."))
   }
 }
@@ -124,7 +124,7 @@ stop_if_not_exists <- function(src_path) {
 #'
 #' @export
 lagos_path <- function() paste0(rappdirs::user_data_dir(appname = "LAGOSNE",
-                appauthor = "LAGOSNE"), .Platform$file.sep)
+  appauthor = "LAGOSNE"), .Platform$file.sep)
 
 lagos_names <- function(dt) purrr::map(dt, names)
 # unlist(lapply(dt, function(x) length(grep("connect", names(x))))) # search tables for column
@@ -153,21 +153,21 @@ lagos_names <- function(dt) purrr::map(dt, names)
 #' query_lagos_names("secchi")
 #' query_lagos_names("conn")
 #' }
-query_lagos_names <- function(grep_string, scale = NA, dt = lagosne_load()){
+query_lagos_names <- function(grep_string, scale = NA, dt = lagosne_load()) {
 
   dt_names <- lagos_names(dt)
   names_matches <- unlist(lapply(dt_names,
-                    function(x) length(grep(grep_string, x)) > 0))
+    function(x) length(grep(grep_string, x)) > 0))
   res <- names(dt_names)[names_matches]
 
   res_filtered <- res[grep(scale, res)]
 
-  if(!is.na(scale)){
-    if(length(res_filtered) < 1 & length(res) > 1){
+  if (!is.na(scale)) {
+    if (length(res_filtered) < 1 & length(res) > 1) {
       stop(paste0("The '", scale, "' scale does not exist!"))
     }
     res_filtered
-  }else{
+  } else {
     res
   }
 }
@@ -184,7 +184,7 @@ query_lagos_names <- function(grep_string, scale = NA, dt = lagosne_load()){
 #' query_column_names(dt, "hu4.chag", "_dep_")
 #' query_column_names(dt, "county.chag", "baseflowindex")
 #' }
-query_column_names <- function(dt, table_name, grep_string){
+query_column_names <- function(dt, table_name, grep_string) {
   dt_names <- lagos_names(dt)
   dt_names[table_name][[1]][grep(grep_string, dt_names[table_name][[1]])]
 }
@@ -200,52 +200,33 @@ query_column_names <- function(dt, table_name, grep_string){
 #' dt <- lagosne_load("1.087.3")
 #' query_column_keywords(dt, "hu12.chag", "hydrology")
 #' }
-query_column_keywords <- function(dt, table_name, keyword_string){
+query_column_keywords <- function(dt, table_name, keyword_string) {
 
-  if(!(keyword_string %in% keyword_partial_key()[,1])){
+  if (!(keyword_string %in% keyword_partial_key()[, 1])) {
     stop("keyword not found in keyword_partial_key()")
   }
 
-  if(!(table_name %in% names(dt))){
+  if (!(table_name %in% names(dt))) {
     stop("table not found in 'dt'")
   }
 
   dt_names <- lagos_names(dt)
 
   match <- keyword_partial_key()[
-    keyword_partial_key()[,1] %in% keyword_string, 2]
+    keyword_partial_key()[, 1] %in% keyword_string, 2]
 
   unlist(lapply(match,
-                function(x) dt_names[table_name][[1]][
-                  grep(x, dt_names[table_name][[1]])
-                ]))
+    function(x) dt_names[table_name][[1]][
+      grep(x, dt_names[table_name][[1]])
+    ]))
 
 }
 
-#' @importFrom curl curl_fetch_memory
-#' @importFrom stringr str_extract
-get_file_names <- function(url){
-  handle <- curl::new_handle(nobody = TRUE)
-
-  headers <- curl::parse_headers(
-    curl::curl_fetch_memory(url, handle)$headers)
-  fname <- headers[grep("filename", headers)]
-
-  res <- stringr::str_extract(fname, "(?<=\\=)(.*?)\\.csv")
-  gsub('\\"', "", res)
-}
-
-#' @importFrom httr GET content
-get_lagos_module <- function(edi_url, pasta_url, folder_name, overwrite){
-
-  id <- httr::content(httr::GET(pasta_url), encoding = "UTF-8")
-  id <- strsplit(id, "\n")[[1]]
-  files <- suppressWarnings(paste0(edi_url, "&entityid=", id))
-
-  file_names <- sapply(files, get_file_names)
-
-  files      <- files[!is.na(file_names)]
-  file_names <- file_names[!is.na(file_names)]
+#' @importFrom xml2 read_xml xml_find_all xml_text
+get_lagos_module <- function(pasta_url, folder_name, overwrite) {
+  xml_files <- xml2::xml_find_all(xml2::read_xml(pasta_url), ".//dataTable")
+  files <- xml2::xml_text(xml2::xml_find_all(xml_files, ".//url"))
+  file_names <- xml2::xml_text(xml2::xml_find_all(xml_files, ".//objectName"))
 
   local_dir   <- file.path(tempdir(), folder_name)
   dir.create(local_dir, showWarnings = FALSE)
@@ -253,10 +234,10 @@ get_lagos_module <- function(edi_url, pasta_url, folder_name, overwrite){
   file_paths <- file.path(local_dir, file_names)
 
   invisible(lapply(seq_len(length(files)),
-    function(i){
+    function(i) {
       message(paste0("Downloading ", file_names[i], " ..."))
       get_if_not_exists(files[i], file_paths[i], overwrite)
-      }))
+    }))
 
   local_dir
 }
@@ -268,17 +249,17 @@ capitalize <- function(string) {
   return(string)
 }
 
-pad_huc_ids <- function(dt, col_name, len){
+pad_huc_ids <- function(dt, col_name, len) {
   id_num <- as.numeric(dt[, col_name])
   res <- formatC(id_num, width = len, digits = 0, format = "f", flag = "0")
-  dt[,col_name] <- as.character(res)
+  dt[, col_name] <- as.character(res)
   dt
 }
 
-format_nonscientific <- function(x){
-  if(is.na(as.numeric(x))){
+format_nonscientific <- function(x) {
+  if (is.na(as.numeric(x))) {
     x
-  }else{
+  } else {
     trimws(
       format(
         as.numeric(x), scientific = FALSE, drop0trailing = TRUE)
@@ -286,37 +267,42 @@ format_nonscientific <- function(x){
   }
 }
 
-tidy_name_prefixes <- function(nms){
+tidy_name_prefixes <- function(nms) {
 
   prefixes_key <- data.frame(prefix      = c("hu4_", "iws_", "state_",
-                                             "nhd_", "hu8_", "hu12_",
-                                             "edu_", "county_", "hu6_",
-                                             "^lakes_",
-                                             "tp_", "toc_", "tn_", "tkn_",
-                                             "tdp_", "tdn_", "srp_",
-                                             "secchi_", "no2no3_", "no2_",
-                                             "nh4_", "doc_", "dkn_", "colort_",
-                                             "colora_", "chla_", "ton_"),
-                             stringsAsFactors = FALSE)
+    "nhd_", "hu8_", "hu12_",
+    "edu_", "county_", "hu6_",
+    "^lakes_",
+    "tp_", "toc_", "tn_", "tkn_",
+    "tdp_", "tdn_", "srp_",
+    "secchi_", "no2no3_", "no2_",
+    "nh4_", "doc_", "dkn_", "colort_",
+    "colora_", "chla_", "ton_"),
+  stringsAsFactors = FALSE)
   prefixes_key$replacement <- rep("", nrow(prefixes_key))
 
   prefix_matches <- list()
-  for(i in seq_along(prefixes_key$prefix)){
+  for (i in seq_along(prefixes_key$prefix)) {
     prefix_matches[[i]] <- stringr::str_which(
       nms$raw, prefixes_key$prefix[i])
   }
 
-  prefix_matches <- tidyr::unnest(tibble::enframe(prefix_matches))
+  prefix_data <- tibble::enframe(prefix_matches)
+  names(prefix_data) <- c("data_names", "display_names")
+  prefix_matches <- tidyr::unnest(
+    cols = c("data_names", "display_names"),
+    data = prefix_data
+  )
   prefix_matches <- apply(prefix_matches, 1, function(x)
     c(nms$raw[x[2]], prefixes_key$prefix[x[1]]))
   prefix_matches <- data.frame(t(prefix_matches), stringsAsFactors = FALSE)
 
-  if(nrow(prefix_matches) != 0 & ncol(prefix_matches) != 0){
+  if (nrow(prefix_matches) != 0 & ncol(prefix_matches) != 0) {
     names(prefix_matches) <- c("raw", "prefix")
     nms <- merge(nms, prefix_matches, all.x = TRUE)
   }
 
-  for(i in seq_along(nms$formatted[!is.na(nms$prefix)])){
+  for (i in seq_along(nms$formatted[!is.na(nms$prefix)])) {
     nms$formatted[!is.na(nms$prefix)][i] <-
       gsub(
         nms$prefix[!is.na(nms$prefix)][i], "",
@@ -327,19 +313,19 @@ tidy_name_prefixes <- function(nms){
   nms
 }
 
-key_names <- function(nms){
+key_names <- function(nms) {
   # match cleaned names to a key
   name_key <- data.frame(formatted  = c("ha", "perimkm",
-                                        "maxdepth", "lake_perim_meters",
-                                        "lakeareaha", "samplemonth",
-                                        "sampleyear", "sampledate",
-                                        "meandepth", "zoneid"),
-                         cleaned = c("Area (ha)", "Perimeter (km)",
-                                     "Max Depth", "Perimeter (m)",
-                                     "Lake Area (ha)", "Month",
-                                     "Year", "Date",
-                                     "Mean Depth", "ID"),
-                         stringsAsFactors = FALSE)
+    "maxdepth", "lake_perim_meters",
+    "lakeareaha", "samplemonth",
+    "sampleyear", "sampledate",
+    "meandepth", "zoneid"),
+  cleaned = c("Area (ha)", "Perimeter (km)",
+    "Max Depth", "Perimeter (m)",
+    "Lake Area (ha)", "Month",
+    "Year", "Date",
+    "Mean Depth", "ID"),
+  stringsAsFactors = FALSE)
   nms <- merge(nms, name_key, all.x = TRUE)
 
   nms$formatted[is.na(nms$formatted)] <-
@@ -349,27 +335,27 @@ key_names <- function(nms){
   nms
 }
 
-tidy_name_suffixes <- function(nms){
+tidy_name_suffixes <- function(nms) {
   # match suffixes to a key
   suffixes_key <- data.frame(raw       = c("_count$", "_ha$", "_km$",
-                                           "_m$", "_pct$", "_mperha$",
-                                           "_pointsperha$", "_pointspersqkm$",
-                                           "_pointcount$"),
-                             formatted = c(" (n)", " (ha)", " (km)",
-                                           " (m)", " (%)", " (n/ha)",
-                                           " (n/ha)", " (n/km2)", " (n)"),
-                             stringsAsFactors = FALSE)
+    "_m$", "_pct$", "_mperha$",
+    "_pointsperha$", "_pointspersqkm$",
+    "_pointcount$"),
+  formatted = c(" (n)", " (ha)", " (km)",
+    " (m)", " (%)", " (n/ha)",
+    " (n/ha)", " (n/km2)", " (n)"),
+  stringsAsFactors = FALSE)
 
-  for(i in seq_along(suffixes_key$raw)){
+  for (i in seq_along(suffixes_key$raw)) {
     nms$cleaned <- gsub(suffixes_key$raw[i],
-                        suffixes_key$formatted[i],
-                        nms$cleaned, fixed = FALSE)
+      suffixes_key$formatted[i],
+      nms$cleaned, fixed = FALSE)
   }
 
   nms
 }
 
-url_exists <- function(url){
+url_exists <- function(url) {
   handle <- curl::new_handle(nobody = TRUE)
 
   tryCatch(
