@@ -3,8 +3,7 @@ context("display_names")
 test_that("display_names works", {
 
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+  skip_on_ci()
 
   lg <- lagosne_load()
 
